@@ -10,6 +10,7 @@ use IO::Socket::INET;
 use IO::Socket::INET6;
 use Try::Tiny;
 use Capture::Tiny ':all';
+use IPv6::Address;
 
 =head1 NAME
 
@@ -17,11 +18,11 @@ Net::Hacky::Detect::IP - Hackily try different methods of attaining local system
 
 =head1 VERSION
 
-Version 0.017
+Version 0.018
 
 =cut
 
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 my $tools = {
     unix => {
@@ -80,7 +81,7 @@ Create a new object for interacting with Net-Hacky-Detect-IP
 =cut 
 
 sub new {
-    my ($class,$PND,$AutoStart,$debug) = @_;
+    my ($class) = @_;
 
     # Some private stuff for ourself
     my $self = {
@@ -184,11 +185,28 @@ sub scan {
         elsif ( ($type == 6 || $type == 0) && $testIP =~ m#:# && $testIP =~ m#[0-9]# && $testIP =~ m#^([a-f0-9:]+)$#) {
             # Copy $1 to $IP because it looks prettier
             my $IP = $1;
+            my $test;
+        
+            # Can sometimes overread ipv6 IP:PORT's due to the : seperator deal with that here
+            # Test its valid
+            if ($IP =~ m#^(.*):\d+$#) {
+                try {
+                    $test = IPv6::Address->new($IP);
+                };
+                $IP = $1;
+            }
             
+            # Incase we had ports on our ipv6
+            if (!$test) {
+                try {
+                    $test = IPv6::Address->new($IP);
+                };
+            }
+
             # Check we have not already dealt with this ip and its valid
             next if ($unique->{$IP});
             $unique->{$IP} = 1;
-            if (!$self->_checkIP6($IP)) { next }
+            if (!$test || !$self->_checkIP6($IP)) { next }
 
             # Push the valid ip into the return space
             push @$return,$IP;
@@ -221,6 +239,65 @@ sub checkIP {
     }
 }
 
+=head2 is_public
+
+Return 1 if an address is a publically routed address.
+
+Return 0 if it is not.
+
+=cut
+
+sub is_public {
+    my ($self,$ip) = @_;
+
+    
+}
+
+=head2 is_private
+
+Return 1 if an address is a privately routed 'LAN' address.
+
+Return 0 if it is not.
+
+=cut
+
+sub is_private {
+    my ($self,$ip) = @_;
+
+    
+}
+
+=head2 is_outbound
+
+Return 1 if an address can be bound to, to access the internet.
+
+Return 0 if it is not.
+
+=cut
+
+sub is_outbound {
+    my ($self,$ip) = @_;
+    
+    my $return = 0;
+
+    if ($host =~ m#\.#) { 
+        my $sock = IO::Socket::INET->new(
+            LocalAddr   =>  $host,
+            LocalPort   =>  $port,
+            Proto       =>  'tcp',
+            ReuseAddr   =>  1
+        ) or $fail = 0;
+    } 
+    elsif ($host =~ m#:#) {
+        return $self->_checkIP6($host);
+    }
+    else { 
+        warn "$host does not look like an IPv6 nor IPv4, ignored.";
+    }
+
+    return $return;
+}
+
 
 sub _checkIP4 {
     my ($self,$host) = @_;
@@ -271,7 +348,7 @@ sub _checkIP6 {
         warn "Incorrect number of arguments, returning fail";
         return 0;
     }
-
+    
     # By default fail the bind
     my $bindsuccess = 0;
 
